==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescription } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("NewValue", "Unknown");
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b(a);
        a.aa("PropertyEditorPropertyDescriptionChangedEventArgs", function () { return new PropertyEditorPropertyDescriptionChangedEventArgsDescription(); });
        a.z("PropertyEditorPropertyDescriptionChangedEventArgs", PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescription } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("NewValue", "Unknown");
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b(a);
        a.ac("PropertyEditorPropertyDescriptionChangedEventArgs", function () { return new PropertyEditorPropertyDescriptionChangedEventArgsDescription(); });
        a.ab("PropertyEditorPropertyDescriptionChangedEventArgs", PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata };
